@@ -109,7 +109,7 @@ class LDA(TLTTopicModel):
             if numb_docs != 0:
                 self.numb_docs = numb_docs
                 #print('NUMB docs: ', self.numb_docs)
-                print('Extracting topic distribution from docs in ', path)
+                #print('Extracting topic distribution from docs in ', path)
             else:
                 print('No txt file in: ', path)
 
@@ -120,7 +120,8 @@ class LDA(TLTTopicModel):
             if self.numb_docs != numb_docs:
                 raise DocsError("Please write the correct number of docs as input or do not insert it in case you give a docs_folder")
             else:
-                print('Extracting topic distribution from docs in ', path)
+                pass
+                #print('Extracting topic distribution from docs in ', path)
 
         elif self.numb_docs != None and self._docs_path == None and self._items_descr_path == None:
             mode = 'gen'
@@ -140,6 +141,7 @@ class LDA(TLTTopicModel):
             Exponent of the pareto distribution for documents
             viralities.
         '''
+        #print('vir_exp', virality_exp)
         viralities = random_powerlaw_vec(gamma=virality_exp, dimensions=self.numb_docs)
 
         if np.size(viralities) == self.numb_docs:
@@ -174,6 +176,7 @@ class LDA(TLTTopicModel):
         model : Gensim obj
             trained Gensim lda model
         '''
+        print('Extracting topic distribution from docs in ', path)
         docs = read_docs(path, verbose=False)
         corpus = self.preprocess_texts(docs)
         gammas = {}
@@ -209,7 +212,7 @@ class LDA(TLTTopicModel):
         #print(docs)
         preproc_docs = [gensim.parsing.preprocessing.remove_stopwords((sent[0].lower())) for sent in docs if len(sent) !=0]
         #print(preproc_docs)
-        data_words = self.sent_to_words(preproc_docs)
+        data_words = self.sent_to_words(preproc_docs, verbose=False)
         #print(data_words)
         for item in range(self.numb_docs):
             self.items_keyw[item] = self.to_bow(data_words[item])
@@ -339,12 +342,12 @@ class LDA(TLTTopicModel):
         # Remove to
         data = [re.sub(r'to', '', str(sent)) for sent in data]
 
-        data_words = self.sent_to_words(data)
+        data_words = self.sent_to_words(data, verbose=False)
         corpus = [self.dictionary.doc2bow(word) for word in data_words]
         return corpus
 
 
-    def sent_to_words(self, docs):
+    def sent_to_words(self, docs, verbose=True):
         '''
         Returns list of docs divided in words
 
@@ -359,8 +362,12 @@ class LDA(TLTTopicModel):
             list of lists: each entry is the list of words of one doc
         '''
         data_words = []
-        for sentence in docs:
-            data_words.append(gensim.utils.simple_preprocess(str(sentence), deacc=True))
+        if verbose:
+            for sentence in self._progress_bar(docs):
+                data_words.append(gensim.utils.simple_preprocess(str(sentence), deacc=True))
+        else:
+            for sentence in docs:
+                data_words.append(gensim.utils.simple_preprocess(str(sentence), deacc=True))
         return list(data_words)
 
 
@@ -381,9 +388,10 @@ class LDA(TLTTopicModel):
         -------
         gensim lda model object
         '''
+        print('Training LDA model..')
         docs = read_docs(self._training_path)
         #print('len docs ', len(docs))
-        data_words = self.sent_to_words(docs)
+        data_words = self.sent_to_words(docs, verbose=False)
 
         self.dictionary = gensim.corpora.Dictionary(data_words)
         corpus = self.preprocess_texts(docs)
